@@ -56,7 +56,7 @@ process = subprocess.Popen(cmd,cwd=projectdir, shell=True, stderr=sys.stderr)
 begintime = datetime.datetime.now()
 if process:
     pid = process.pid
-    print >>sys.stderr, "[CLAM Dispatcher] Running with pid " + str(pid)
+    print >>sys.stderr, "[CLAM Dispatcher] Running with pid " + str(pid) + " (" + begintime.strftime('%Y-%m-%d %H:%M:%S') + ")"
     sys.stderr.flush()
     f = open(projectdir + '.pid','w')
     f.write(str(pid))
@@ -72,19 +72,26 @@ else:
 #intervalf = lambda s: min(s/10.0, 15)
 abortchecktime = 0
 idle = 0
+done = False
 
-while True:    
-    duration = datetime.datetime.now() - begintime
-    d = duration.microseconds / 1000000.0
+def total_seconds(delta):
+    return delta.days * 86400 + delta.seconds + (delta.microseconds / 1000000.0)
+
+while not done:    
+    d = total_seconds(datetime.datetime.now() - begintime)        
     try:
         returnedpid, statuscode = os.waitpid(pid, os.WNOHANG)
         if returnedpid != 0:
-            print >>sys.stderr, "[CLAM Dispatcher] Process ended (" + str(d)+"s) "
-            break
+            print >>sys.stderr, "[CLAM Dispatcher] Process ended (" + datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S') + ", " + str(d)+"s) "
+            done = True    
     except OSError: #no such process
-        print >>sys.stderr, "[CLAM Dispatcher] Process lost! (" + str(d)+"s)"
+        print >>sys.stderr, "[CLAM Dispatcher] Process lost! (" + datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S') + ", " + str(d)+"s)"
         statuscode = 1
-        break         
+        done = True        
+
+    if done:
+        break    
+    
     abortchecktime += d
     if abortchecktime >= d+0.1 or abortchecktime >= 10: #every 10 seconds, faster at beginning
         abortchecktime = 0                
@@ -117,7 +124,7 @@ f.write(str(statuscode))
 f.close()
 os.unlink(projectdir + '.pid')
 
-d = duration.microseconds / 1000000.0  
+d = total_seconds(datetime.datetime.now() - begintime)
 print >>sys.stderr, "[CLAM Dispatcher] Finished (" + datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S') + "), exit code " + str(statuscode) + ", dispatcher wait time " + str(idle)  + "s, duration " + str(d) + "s"
  
 sys.exit(statuscode)
