@@ -53,7 +53,7 @@ except ImportError:
 #web.wsgiserver.CherryPyWSGIServer.ssl_private_key = "path/to/ssl_private_key"
 
 
-VERSION = '0.7.8'
+VERSION = '0.7.9'
 
 DEBUG = False
     
@@ -249,6 +249,7 @@ class CLAMService(object):
 
     urls = (
         settings.STANDALONEURLPREFIX + '/', 'Index',
+        settings.STANDALONEURLPREFIX + '/info/?', 'Info',
         settings.STANDALONEURLPREFIX + '/data.js', 'InterfaceData', #provides Javascript data for the web interface
         settings.STANDALONEURLPREFIX + '/style.css', 'StyleData', #provides stylesheet for the web interface
         settings.STANDALONEURLPREFIX + '/(?:[A-Za-z0-9_]*)/(?:input|output)/folia.xsl', 'FoLiAXSL', #provides the FoLiA XSL in every output directory without it actually existing there
@@ -337,7 +338,33 @@ class Index(object):
 
 
         web.header('Content-Type', "text/xml; charset=UTF-8")
-        return render.response(VERSION, settings.SYSTEM_ID, settings.SYSTEM_NAME, settings.SYSTEM_DESCRIPTION, user, None, getrooturl(), -1 ,"",[],0, errors, errormsg, settings.PARAMETERS,corpora, None,None, settings.PROFILES, None, projects, settings.WEBSERVICEGHOST if self.GHOST else False)
+        return render.response(VERSION, settings.SYSTEM_ID, settings.SYSTEM_NAME, settings.SYSTEM_DESCRIPTION, user, None, getrooturl(), -1 ,"",[],0, errors, errormsg, settings.PARAMETERS,corpora, None,None, settings.PROFILES, None, projects, settings.WEBSERVICEGHOST if self.GHOST else False, False)
+    
+class Info(object):    
+    GHOST = False
+    @RequireLogin(ghost=GHOST)
+    def GET(self, user = None):
+        """Get list of projects"""
+        projects = []
+        if not user: user = 'anonymous'
+        for f in glob.glob(settings.ROOT + "projects/" + user + "/*"): #TODO LATER: Implement some kind of caching
+            if os.path.isdir(f):
+                d = datetime.datetime.fromtimestamp(os.stat(f)[8])  
+                project = os.path.basename(f)
+                projects.append( ( project , d.strftime("%Y-%m-%d %H:%M:%S") ) )
+
+        errors = "no"
+        errormsg = ""
+
+        corpora = CLAMService.corpusindex()
+
+        render = web.template.render(settings.CLAMDIR + '/templates')
+
+
+        web.header('Content-Type', "text/xml; charset=UTF-8")
+        return render.response(VERSION, settings.SYSTEM_ID, settings.SYSTEM_NAME, settings.SYSTEM_DESCRIPTION, user, None, getrooturl(), -1 ,"",[],0, errors, errormsg, settings.PARAMETERS,corpora, None,None, settings.PROFILES, None, projects, settings.WEBSERVICEGHOST if self.GHOST else False, True)
+    
+
         
 
 def getrooturl():
@@ -612,7 +639,7 @@ class Project(object):
         
 
         web.header('Content-Type', "text/xml; charset=UTF-8")
-        return render.response(VERSION, settings.SYSTEM_ID, settings.SYSTEM_NAME, settings.SYSTEM_DESCRIPTION, user, project, getrooturl(), statuscode, statusmsg, statuslog, completion, errors, errormsg, parameters,settings.INPUTSOURCES, outputpaths,inputpaths, settings.PROFILES, datafile, None , settings.WEBSERVICEGHOST if self.GHOST else False)
+        return render.response(VERSION, settings.SYSTEM_ID, settings.SYSTEM_NAME, settings.SYSTEM_DESCRIPTION, user, project, getrooturl(), statuscode, statusmsg, statuslog, completion, errors, errormsg, parameters,settings.INPUTSOURCES, outputpaths,inputpaths, settings.PROFILES, datafile, None , settings.WEBSERVICEGHOST if self.GHOST else False, False)
         
                     
     @RequireLogin(ghost=GHOST)
@@ -649,11 +676,11 @@ class Project(object):
 
         errors, parameters, commandlineparams = clam.common.data.processparameters(postdata, settings.PARAMETERS)
                                                 
-
-        if not sufficientresources():            
-            printlog("*** NOT ENOUGH SYSTEM RESOURCES AVAIABLE ***")
+        sufresources, resmsg = sufficientresources()
+        if not sufresources:            
+            printlog("*** NOT ENOUGH SYSTEM RESOURCES AVAILABLE: " + resmsg + " ***")
             #TODO: Use 503 instead of 500 (but 503 not implemented in web.py)
-            raise web.webapi.InternalError("There are not enough system resources available to accomodate your request. Please try again later.")
+            raise web.webapi.InternalError("There are not enough system resources available to accomodate your request. " + resmsg + " .Please try again later.")
 
         if not errors: #We don't even bother running the profiler if there are errors
             matchedprofiles = clam.common.data.profiler(settings.PROFILES, Project.path(project, user), parameters, settings.SYSTEM_ID, settings.SYSTEM_NAME, getrooturl(), printdebug)
@@ -772,6 +799,7 @@ class OutputFileHandler(object):
                     if v.id == requestid:
                         viewer = v
                 if viewer:                    
+                    web.header('Content-Type', viewer.mimetype)
                     output = viewer.view(outputfile, **web.input())
                     if isinstance(output, web.template.TemplateResult):
                        output =  output['__body__']
@@ -1531,6 +1559,8 @@ class ProjectGhost(Project):
 class IndexGhost(Index):
     GHOST=True
 
+class InfoGhost(Info):
+    GHOST=True
         
 #class Uploader(object): #OBSOLETE!
 
@@ -1790,7 +1820,7 @@ def sufficientresources():
                     cached = float(line[9:].replace('kB','').strip()) #in kB
             f.close()
             if settings.REQUIREMEMORY * 1024 > memfree + cached:
-                return False                                
+                return False, str(settings.REQUIREMEMORY * 1024) + " kB memory is required but only " + str(memfree + cached) + " is available."                            
     if settings.MAXLOADAVG > 0:
         if not os.path.exists('/proc/loadavg'):
             printlog("WARNING: No /proc/loadavg available on your system! Not Linux? Skipping load average check!")
@@ -1800,7 +1830,7 @@ def sufficientresources():
             loadavg = float(line.split(' ')[0])
             f.close()
             if settings.MAXLOADAVG < loadavg:
-                return False
+                return False, "System load too high: " + str(loadavg) + ", max is " + str(settings.MAXLOADAVG)   
     if settings.MINDISKSPACE and settings.DISK:
         dffile = '/tmp/df.' + str("%034x" % random.getrandbits(128))
         ret = os.system('df -m ' + settings.DISK + " | gawk '{ print $4; }'  > " + dffile)
@@ -1811,14 +1841,14 @@ def sufficientresources():
                 f.close()
                 if free < settings.MINDISKFREE:
                     os.unlink(dffile)
-                    return False
+                    return False, "Not enough diskspace, " + str(free) + " MB free, need at least " + str(settings.MINDISKFREE) + " MB"
             except:
                 printlog("WARNING: df " + settings.DISK + " failed (unexpected format). Skipping disk space check!")                                                
                 os.unlink(dffile)
 
         else:
             printlog("WARNING: df " + settings.DISK + " failed. Skipping disk space check!")        
-    return True
+    return True, ""
         
 
 
@@ -1889,6 +1919,7 @@ def set_defaults(HOST = None, PORT = None):
     elif settings.WEBSERVICEGHOST:
         CLAMService.urls = (
             settings.STANDALONEURLPREFIX + '/' + settings.WEBSERVICEGHOST + '/', 'IndexGhost',
+            settings.STANDALONEURLPREFIX + '/' + settings.WEBSERVICEGHOST + '/info/?', 'InfoGhost',
             settings.STANDALONEURLPREFIX + '/' + settings.WEBSERVICEGHOST + '/([A-Za-z0-9_]*)/?', 'ProjectGhost',    
             settings.STANDALONEURLPREFIX + '/' + settings.WEBSERVICEGHOST + '/([A-Za-z0-9_]*)/output/(.*)/?', 'OutputFileHandlerGhost', #(also handles viewers, convertors, metadata, and archive download
             settings.STANDALONEURLPREFIX + '/' + settings.WEBSERVICEGHOST + '/([A-Za-z0-9_]*)/input/(.*)/?', 'InputFileHandlerGhost',
