@@ -36,7 +36,7 @@ from clam.common.util import RequestWithMethod
 
 #clam.common.formats is deliberately imported _at the end_ 
 
-VERSION = '0.7.8'
+VERSION = '0.7.9'
 
 class FormatError(Exception):
      """This Exception is raised when the CLAM response is not in the valid CLAM XML format"""
@@ -139,7 +139,8 @@ class CLAMFile:
                 for line in open(self.projectpath + self.basedir + '/' + self.filename, 'r').readlines():
                     yield line
         else:        
-            response = urllib2.urlopen(urllib2.Request( self.projectpath + self.basedir + '/' + self.filename))      
+            fullpath = self.projectpath + self.basedir + '/' + self.filename
+            response = urllib2.urlopen(urllib2.Request( fullpath))      
             for line in response.readlines():
                 if not isinstance(line,unicode) and self.metadata and 'encoding' in self.metadata :
                     yield unicode(line, self.metadata['encoding'])
@@ -173,17 +174,18 @@ class CLAMFile:
 
     def readlines(self):
         """Loads all in memory"""
-        if not self.remote:
-            if self.metadata and 'encoding' in self.metadata:
-               return codecs.open(self.projectpath + self.basedir + '/' + self.filename, 'r', self.metadata['encoding']).readlines()
-            else:
-               return open(self.projectpath + self.basedir + '/' + self.filename, 'r').readlines()
-        else:
-            response = urllib2.urlopen(urllib2.Request( self.projectpath + self.basedir + '/' + self.filename))      
-            content = response.read()
-            if not isinstance(content,unicode) and self.metadata and 'encoding' in self.metadata :
-                content = unicode(content, self.metadata['encoding'])
-            return response
+        #if not self.remote:
+        #    if self.metadata and 'encoding' in self.metadata:
+        #       return codecs.open(self.projectpath + self.basedir + '/' + self.filename, 'r', self.metadata['encoding']).readlines()
+        #    else:
+        #       return open(self.projectpath + self.basedir + '/' + self.filename, 'r').readlines()
+        #else:
+        #    response = urllib2.urlopen(urllib2.Request( self.projectpath + self.basedir + '/' + self.filename))      
+        #    content = response.read()
+        #    if not isinstance(content,unicode) and self.metadata and 'encoding' in self.metadata :
+        #        content = unicode(content, self.metadata['encoding'])
+        #    return response
+        return list(iter(self))
             
     def copy(self, target):
         if self.metadata and 'encoding' in self.metadata:
