@@ -101,13 +101,41 @@ PROFILES = [
             copymetadata=True,
             multi=True,
         ),        
-    )
+    ),
+    Profile(
+        InputTemplate('foliainput', FoLiAXMLFormat,"FoLiA XML document", 
+            multi=True,
+        ),
+        OutputTemplate('mainoutput', TadpoleFormat,"Frog Columned Output (legacy)",  #named 'mainoutput' for legacy reasons
+            SetMetaField('tokenisation','yes'),
+            SetMetaField('postagging','yes'),
+            SetMetaField('lemmatisation','yes'),
+            SetMetaField('morphologicalanalysis','yes'),
+            ParameterCondition(skip_contains='m',
+                then=SetMetaField('mwudetection','no'),
+                otherwise=SetMetaField('mwudetection','yes'), 
+            ),                        
+            ParameterCondition(skip_contains='p',
+                then=SetMetaField('parsing','no'),
+                otherwise=SetMetaField('parsing','yes'),
+            ),            
+            extension='.frog.out',
+            copymetadata=True,
+            multi=True,
+        ),
+        OutputTemplate('foliaoutput', FoLiAXMLFormat,"FoLiA Document",
+            FoLiAViewer(), 
+            copymetadata=True,
+            multi=True,
+        ),        
+    ),    
+    
 ]
 
 PARAMETERS =  [
 
     ('Modules', [
-        ChoiceParameter('skip', 'Skip modules','Are there any components you want to skip? Skipping the parser and chunker speeds up the process considerably.',paramflag='--skip=',choices=[('t','Tokeniser'),('m','Multi-Word Detector'),('p','Parser'),('c','Chunker / Shallow parser')], multi=True ),        
+        ChoiceParameter('skip', 'Skip modules','Are there any components you want to skip? Skipping components you do not need may speed up the process considerably.',paramflag='--skip=',choices=[('t','Tokeniser'),('m','Multi-Word Detector'),('p','Parser'),('c','Chunker / Shallow parser'),('n','Named Entity Recognition')], multi=True ),        
         #ChoiceParameter('skip', 'Skip Components','Are there any components you want to skip? Skipping the parser speeds up the process considerably.',paramflag='--skip=',choices=[('p','Skip dependency parser'),('n',"Don't skip anything")] ),
     ]),     
 ]
